@@ -3,23 +3,19 @@ from typing import Any, Iterable, Union, List  # To make stuff look nicer
 
 # Custom Classes:
 from .pymadClasses import madReference
-from .mad_process import mad_process 
+from .mad_process import mad_process
 
 # TODO: Make it so that MAD does the loop for variables not python (speed)
 
 
 class last_counter():
     def __init__(self, size: int, mad_process):
-        self.counter = list(range(size, 0, -1)) 
+        self.counter = list(range(size, 0, -1))
         self.mad_process = mad_process
-        self.max_used = 0
 
     def get(self):
         assert len(self.counter) != 0, "Assigned too many anonymous, variables, increase num_temp_vars or assign the variables into MAD"
-        val = self.counter.pop()
-        if val > self.max_used:
-            self.max_used = val
-        return f"__last__[{val}]"
+        return f"__last__[{self.counter.pop()}]"
     
     def set(self, idx):
         self.counter.append(idx)
@@ -128,7 +124,7 @@ class MAD(object):  # Review private and public
         """
         return self.__process.recv(varname)
 
-    def receive( 
+    def receive(
         self, varname: str = None
     ) -> Union[str, int, float, np.ndarray, bool, list]:
         """See :meth:`recv`"""
@@ -199,7 +195,7 @@ class MAD(object):  # Review private and public
         return self.send(f"py:__err(true); {string}; py:__err(false);")
 
     def load(self, module: str, vars: List[str] = []):
-        """Load modules into the MAD-NG environment
+        """Import modules into the MAD-NG environment
 
         Retrieve the classes in MAD-NG from the module ``module``, while only importing the classes in the list ``vars``.
         If no list is provided, it is assumed that you would like to import every class from the module.
@@ -457,5 +453,3 @@ class MAD(object):  # Review private and public
         del self
 
     # ---------------------------------------------------------------------------------------------------#
-    def __del__(self):
-        print("max references used:", self.__last_counter.max_used)
\ No newline at end of file
